@@ -102,6 +102,8 @@ class Pledge(CreateUpdateModel, TranslatedMixin):
         tracked in the provider implementation. Based on the outcoming of the
         payment process, the payment provider must change the pledge status. """
 
+    # TODO: Define processing state
+
     UNAUTHORIZED = 10
     AUTHORIZED = 20
     PAID = 30
@@ -150,6 +152,10 @@ class Pledge(CreateUpdateModel, TranslatedMixin):
         self.currency = self.project.currency
         super(Pledge, self).save(*args, **kwargs)
 
+    @property
+    def amount_display(self):
+        return u'%s %s' % (self.amount, self.currency)
+
 
 class Reward(CreateUpdateModel, TranslatedMixin):
     """ A reward is a give-away for backers that pledge a certain amount.
@@ -436,6 +442,11 @@ class Project(Base, TranslatedMixin):
     @property
     def authorized_pledges(self):
         return self.pledges.filter(status__gte=Pledge.AUTHORIZED)
+        
+        
+    @property
+    def collectable_pledges(self):
+        return self.pledges.filter(status=Pledge.AUTHORIZED)
 
     @property
     def has_pledges(self):
